import {
	Avatar,
	Grid,
	Table,
	TableBody,
	TableCell,
	TableRow,
} from "@material-ui/core";
import React from "react";
import {
	ComunicUser,
	ComunicUsersHelper,
} from "../../helpers/ComunicUsersHelper";
import { AsyncWidget } from "../widgets/AsyncWidget";
import { CustomCard } from "../widgets/CustomCard";
import { PageTitle } from "../widgets/PageTitle";
import { TimestampWidget } from "../widgets/TimestampWidget";

interface UserProperty {
	name: string;
	value?: string | number;
	bool?: boolean;
	child?: React.ReactElement;
}

/**
 * Comunic user management route
 *
 * @author Pierre Hubert
 */
export class ComunicUserRoute extends React.Component<
	{ userID: number },
	{ user: ComunicUser }
> {
	constructor(p: any) {
		super(p);

		this.load = this.load.bind(this);
		this.build = this.build.bind(this);
	}

	get user(): ComunicUser {
		return this.state.user;
	}

	async load() {
		const user = await ComunicUsersHelper.GetSingle(this.props.userID);

		this.setState({ user: user });
	}

	get userProperties(): UserProperty[] {
		return [
			{ name: "Account ID", value: this.user.id },
			{ name: "First name", value: this.user.first_name },
			{ name: "Last name", value: this.user.last_name },
			{ name: "Email address", value: this.user.email },
			{
				name: "Account creation time",
				child: (
					<TimestampWidget time={this.user.account_creation_time} />
				),
			},
			{ name: "Page visibility", value: this.user.page_visibility },
			{
				name: "Virtual directory",
				value: this.user.directory ? "@" + this.user.directory : "None",
			},
			{
				name: "Account image",
				child: <Avatar src={this.user.account_image} />,
			},
			{
				name: "Account image visibility",
				value: this.user.account_image_visibility,
			},
			{
				name: "Is friend list public",
				bool: this.user.friend_list_public,
			},
			{
				name: "Is email address public",
				bool: this.user.is_email_public,
			},
			{
				name: "Personal website",
				value: this.user.personal_website,
			},
			{
				name: "Public note",
				value: this.user.public_note,
			},
			{ name: "Location", value: this.user.location },
			{ name: "Block comments", bool: this.user.block_comments },
			{
				name: "Allow posts from friends",
				bool: this.user.allow_posts_from_friends,
			},
			{ name: "Allow emails", bool: this.user.allow_mails },
			{ name: "Language", value: this.user.lang },
		];
	}

	build() {
		return (
			<>
				<PageTitle
					name={this.user.first_name + " " + this.user.last_name}
				/>

				<Grid container spacing={3}>
					<Grid item xs={6}>
						<CustomCard title="General information">
							<Table>
								<TableBody>
									{this.userProperties.map((p) => {
										return (
											<TableRow key={p.name}>
												<TableCell
													style={{
														fontWeight: "bold",
													}}
												>
													{p.name}
												</TableCell>
												<TableCell>
													{p.child != null
														? p.child
														: p.bool != null
														? p.bool
															? "Yes"
															: "No"
														: p.value == null
														? "Undefined"
														: p.value}
												</TableCell>
											</TableRow>
										);
									})}
								</TableBody>
							</Table>
						</CustomCard>
					</Grid>
				</Grid>
			</>
		);
	}

	render() {
		return (
			<AsyncWidget
				key={this.props.userID}
				load={this.load}
				errorMessage="Failed to load user information!"
				onBuild={this.build}
			/>
		);
	}
}
